
# Type: objectidentifier


A URI or CURIE that represents an object in the model.

URI: [https://example.com/test62/meta:types/Objectidentifier](https://example.com/test62/meta:types/Objectidentifier)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **ElementIdentifier** |
| Representation | | str |

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | Used for inheritence and type checking |

